# BillRunStatus

A bill run can have one of the following possible [statuses](https://knowledgecenter.zuora.com/Zuora_Billing/Bill_your_customers/Automate_billing_document_generation/Bill_runs/AA_Get_started_with_bill_runs#Bill_run_status_types).  The status provides information about how the bill run is being processed in Zuora. 

## Enum

* `PENDING` (value: `'Pending'`)

* `PROCESSING` (value: `'Processing'`)

* `COMPLETED` (value: `'Completed'`)

* `ERROR` (value: `'Error'`)

* `CANCELED` (value: `'Canceled'`)

* `POSTED` (value: `'Posted'`)

* `POSTINPROGRESS` (value: `'PostInProgress'`)

* `CANCELINPROGRESS` (value: `'CancelInProgress'`)

* `REMOVEINPROGRESS` (value: `'RemoveInProgress'`)

* `PAUSED` (value: `'Paused'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


